AuthMiddleware

Struct AuthMiddleware 

pub struct AuthMiddleware { /* private fields */ }
Authentication middleware

Protects routes that require authentication. Unauthenticated requests are either redirected to a login page or receive a 401 response.

Example

use ferro_rs::{AuthMiddleware, group, get};

// API routes - return 401 for unauthenticated
group!("/api")
    .middleware(AuthMiddleware::new())
    .routes([...]);

// Web routes - redirect to login
group!("/dashboard")
    .middleware(AuthMiddleware::redirect_to("/login"))
    .routes([...]);

Implementations

Source

impl AuthMiddleware

pub fn new() -> Self

Create middleware that returns 401 Unauthorized if not authenticated

Best for API routes.

pub fn redirect_to(path: impl Into<String>) -> Self

Create middleware that redirects to a login page if not authenticated

Best for web routes.

Example
AuthMiddleware::redirect_to("/login")