pub struct TestContainerGuard;Expand description
Guard that clears the test container when dropped
This ensures test isolation by automatically cleaning up the thread-local test container when the guard goes out of scope.