pub struct DbConnection { /* private fields */ }Expand description
Wrapper around SeaORM’s DatabaseConnection
This provides a clonable, thread-safe connection that can be stored in the application container and shared across requests.
Example
let conn = DbConnection::connect(&config).await?;
// Use with SeaORM queries
let users = User::find().all(conn.inner()).await?;Implementations
Sourceimpl DbConnection
impl DbConnection
Sourcepub async fn connect(config: &DatabaseConfig) -> Result<Self, FrameworkError>
pub async fn connect(config: &DatabaseConfig) -> Result<Self, FrameworkError>
Create a new database connection from config
This establishes a connection pool using the provided configuration. For SQLite databases, this will automatically create the database file if it doesn’t exist.
Sourcepub fn inner(&self) -> &DatabaseConnection
pub fn inner(&self) -> &DatabaseConnection
Sourcepub fn conn(&self) -> &DatabaseConnection
pub fn conn(&self) -> &DatabaseConnection
Methods from Deref<Target = DatabaseConnection>
Sourcepub async fn ping(&self) -> Result<(), DbErr>
pub async fn ping(&self) -> Result<(), DbErr>
Checks if a connection to the database is still valid.
Sourcepub async fn close_by_ref(&self) -> Result<(), DbErr>
pub async fn close_by_ref(&self) -> Result<(), DbErr>
Explicitly close the database connection
Sourcepub fn get_postgres_connection_pool(&self) -> &Pool<Postgres>
pub fn get_postgres_connection_pool(&self) -> &Pool<Postgres>
Sourcepub fn get_sqlite_connection_pool(&self) -> &Pool<Sqlite>
pub fn get_sqlite_connection_pool(&self) -> &Pool<Sqlite>