Module error

Module error 

Framework-wide error types

Provides a unified error type that can be used throughout the framework and automatically converts to appropriate HTTP responses.

Structs

AppError
Simple wrapper for creating one-off domain errors
ValidationErrors
Validation errors with Laravel/Inertia-compatible format

Enums

FrameworkError
Framework-wide error type

Traits

HttpError
Trait for errors that can be converted to HTTP responses