Re-exports
pub use cookie::Cookie;pub use cookie::CookieOptions;pub use cookie::SameSite;pub use resources::PaginationLinks;pub use resources::PaginationMeta;pub use resources::Resource;pub use resources::ResourceCollection;pub use resources::ResourceMap;
Modules
Structs
- Http
Response - HTTP Response builder providing Laravel-like response creation
- Inertia
Redirect - Inertia-aware HTTP Redirect response builder.
- Param
Error - Error type for missing route parameters
- Redirect
- HTTP Redirect response builder
- Redirect
Route Builder - Builder for redirects to named routes with parameters
- Request
- HTTP Request wrapper providing Laravel-like access to request data
- Request
Parts - Request parts after body has been separated
Traits
- Form
Request - Trait for validated form/JSON request data
- From
Param - Trait for types that can be extracted from a single path parameter
- From
Request - Trait for types that can be extracted from an HTTP request
- Response
Ext - Extension trait for Response to enable method chaining on macros
Functions
- bytes
- Create a binary response from raw bytes.
- collect_
body - Collect the full body from an Incoming stream
- json
- Create a JSON response from a serde_json::Value
- parse_
form - Parse bytes as form-urlencoded into the target type
- parse_
json - Parse bytes as JSON into the target type
- text
- Create a text response
Type Aliases
- Response
- Response type alias - allows using
?operator for early returns