Task-local request context accessible from any handler without a Request parameter.
Functions
- request_
host - Return the
Hostheader value (scheme-less, port stripped) for the current request.
Task-local request context accessible from any handler without a Request parameter.
Host header value (scheme-less, port stripped) for the current request.