ResponseExt

Trait ResponseExt 

pub trait ResponseExt {
    // Required methods
    fn status(self, code: u16) -> Self;
    fn header(self, name: impl Into<String>, value: impl Into<String>) -> Self;
}
Extension trait for Response to enable method chaining on macros

Required Methods

fn status(self, code: u16) -> Self

Set the HTTP status code.

fn header(self, name: impl Into<String>, value: impl Into<String>) -> Self

Set a response header, replacing any existing header with the same name (case-insensitive).

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors