Next

Type Alias Next 

pub type Next = Arc<dyn Fn(Request) -> MiddlewareFuture + Send + Sync>;
Type alias for the next handler in the middleware chain

Call next(request).await to pass control to the next middleware or the route handler.

Aliased Type

pub struct Next { /* private fields */ }