Background job queue. Use ferro::queue::Job, ferro::queue::dispatch, etc.
Structs
- Create
Jobs Table - Migration that creates the
jobstable and its indexes. - Failed
JobInfo - A failed job with the error message.
- JobInfo
- Summary of a single job for introspection.
- JobPayload
- Serialized job payload stored in the queue.
- Pending
Dispatch - A pending job dispatch.
- Queue
- Global handle to the queue’s database connection.
- Queue
Config - Queue system configuration.
- Queue
Stats - Aggregate stats across all queues.
- Single
Queue Stats - Per-queue pending/delayed counts.
- Worker
Config - Worker configuration.
- Worker
Loop - DB-backed queue worker.
Enums
Traits
- Job
- A job that can be executed by a queue worker.
- Queueable
- Trait for types that can be dispatched to a queue.
- Tenant
Scope Provider - Injects tenant scope around job execution.
Functions
- dispatch
- Dispatch a job using the global queue.
- dispatch_
later - Dispatch a job with a delay.
- dispatch_
to - Dispatch a job to a specific queue.
- register_
tenant_ capture_ hook - Register the tenant capture hook.
Type Aliases
- Worker
- Type alias for API continuity with callers that use the old
Workername.