RouteDefBuilder

Struct RouteDefBuilder 

pub struct RouteDefBuilder<H> { /* private fields */ }
Builder for route definitions that supports .name() and .middleware() chaining

Implementations

Source

impl<H, Fut> RouteDefBuilder<H>
where H: Fn(Request) -> Fut + Send + Sync + 'static, Fut: Future<Output = Response> + Send + 'static,

pub fn new(method: HttpMethod, path: &'static str, handler: H) -> Self

Create a new route definition builder

pub fn name(self, name: &'static str) -> Self

Name this route for URL generation

pub fn middleware<M: Middleware + 'static>(self, middleware: M) -> Self

Add middleware to this route

pub fn mcp_tool_name(self, name: &str) -> Self

Override the auto-generated MCP tool name for this route

pub fn mcp_description(self, desc: &str) -> Self

Override the auto-generated MCP description for this route

pub fn mcp_hint(self, hint: &str) -> Self

Add a hint that is appended to the MCP description for AI guidance

pub fn mcp_hidden(self) -> Self

Hide this route from MCP tool discovery

pub fn register(self, router: Router) -> Router

Register this route definition with a router

Source

impl<H, Fut> RouteDefBuilder<H>
where H: Fn(Request) -> Fut + Send + Sync + 'static, Fut: Future<Output = Response> + Send + 'static,

pub fn into_group_route(self) -> GroupRoute

Convert this route definition to a type-erased GroupRoute

This is used internally when adding routes to a group.