DatabaseSessionDriver

Struct DatabaseSessionDriver 

pub struct DatabaseSessionDriver { /* private fields */ }
Database session driver using SeaORM

Stores sessions in a sessions table with dual timeout enforcement:

  • Idle timeout: expires after inactivity (based on last_activity)
  • Absolute timeout: expires after creation time (based on created_at)

Both timeouts are checked on every read() and enforced during gc().

Implementations

Source

impl DatabaseSessionDriver

pub fn new(idle_lifetime: Duration, absolute_lifetime: Duration) -> Self

Create a new database session driver with dual timeout configuration