pub struct QueueConnection { /* private fields */ }Expand description
A connection to the queue backend.
Implementations
Sourceimpl QueueConnection
impl QueueConnection
Sourcepub async fn new(config: QueueConfig) -> Result<QueueConnection, Error>
pub async fn new(config: QueueConfig) -> Result<QueueConnection, Error>
Create a new queue connection.
Sourcepub fn config(&self) -> &QueueConfig
pub fn config(&self) -> &QueueConfig
Get the configuration.
Sourcepub async fn pop(&self, queue: &str) -> Result<Option<JobPayload>, Error>
pub async fn pop(&self, queue: &str) -> Result<Option<JobPayload>, Error>
Pop a job from a queue (blocking).
Sourcepub async fn pop_nowait(&self, queue: &str) -> Result<Option<JobPayload>, Error>
pub async fn pop_nowait(&self, queue: &str) -> Result<Option<JobPayload>, Error>
Pop a job from a queue (non-blocking).
Sourcepub async fn migrate_delayed(&self, queue: &str) -> Result<usize, Error>
pub async fn migrate_delayed(&self, queue: &str) -> Result<usize, Error>
Move delayed jobs that are ready to the main queue.
Sourcepub async fn release(
&self,
payload: JobPayload,
delay: Duration,
) -> Result<(), Error>
pub async fn release( &self, payload: JobPayload, delay: Duration, ) -> Result<(), Error>
Release a job back to the queue (for retry).
Sourcepub async fn fail(
&self,
payload: JobPayload,
error: &Error,
) -> Result<(), Error>
pub async fn fail( &self, payload: JobPayload, error: &Error, ) -> Result<(), Error>
Mark a job as failed.
Sourcepub async fn size(&self, queue: &str) -> Result<usize, Error>
pub async fn size(&self, queue: &str) -> Result<usize, Error>
Get the number of jobs in a queue.
Sourcepub async fn delayed_size(&self, queue: &str) -> Result<usize, Error>
pub async fn delayed_size(&self, queue: &str) -> Result<usize, Error>
Get the number of delayed jobs in a queue.
Sourcepub async fn get_pending_jobs(
&self,
queue: &str,
limit: usize,
) -> Result<Vec<JobInfo>, Error>
pub async fn get_pending_jobs( &self, queue: &str, limit: usize, ) -> Result<Vec<JobInfo>, Error>
Get pending jobs from a queue (without removing them).
Sourcepub async fn get_delayed_jobs(
&self,
queue: &str,
limit: usize,
) -> Result<Vec<JobInfo>, Error>
pub async fn get_delayed_jobs( &self, queue: &str, limit: usize, ) -> Result<Vec<JobInfo>, Error>
Get delayed jobs from a queue (without removing them).
Sourcepub async fn get_failed_jobs(
&self,
limit: usize,
) -> Result<Vec<FailedJobInfo>, Error>
pub async fn get_failed_jobs( &self, limit: usize, ) -> Result<Vec<FailedJobInfo>, Error>
Get failed jobs (without removing them).
Sourcepub async fn failed_count(&self) -> Result<usize, Error>
pub async fn failed_count(&self) -> Result<usize, Error>
Get the count of failed jobs.