pub struct TaggedCache { /* private fields */ }Expand description
A cache instance with tags for grouped operations.
Implementations
Sourceimpl TaggedCache
impl TaggedCache
Sourcepub async fn get<T>(&self, key: &str) -> Result<Option<T>, Error>where
T: DeserializeOwned,
pub async fn get<T>(&self, key: &str) -> Result<Option<T>, Error>where
T: DeserializeOwned,
Get a value from the cache.
Sourcepub async fn put<T>(
&self,
key: &str,
value: &T,
ttl: Duration,
) -> Result<(), Error>where
T: Serialize,
pub async fn put<T>(
&self,
key: &str,
value: &T,
ttl: Duration,
) -> Result<(), Error>where
T: Serialize,
Put a value in the cache with tags.
Sourcepub async fn put_default<T>(&self, key: &str, value: &T) -> Result<(), Error>where
T: Serialize,
pub async fn put_default<T>(&self, key: &str, value: &T) -> Result<(), Error>where
T: Serialize,
Put a value using the default TTL.
Sourcepub async fn forever<T>(&self, key: &str, value: &T) -> Result<(), Error>where
T: Serialize,
pub async fn forever<T>(&self, key: &str, value: &T) -> Result<(), Error>where
T: Serialize,
Store a value forever.
Sourcepub async fn flush(&self) -> Result<(), Error>
pub async fn flush(&self) -> Result<(), Error>
Flush all cache entries with any of the configured tags.
Sourcepub async fn remember<T, F, Fut>(
&self,
key: &str,
ttl: Duration,
f: F,
) -> Result<T, Error>
pub async fn remember<T, F, Fut>( &self, key: &str, ttl: Duration, f: F, ) -> Result<T, Error>
Get a value or compute it if not cached.
Sourcepub async fn remember_forever<T, F, Fut>(
&self,
key: &str,
f: F,
) -> Result<T, Error>
pub async fn remember_forever<T, F, Fut>( &self, key: &str, f: F, ) -> Result<T, Error>
Get a value or compute it, caching forever.