Expect

Struct Expect 

pub struct Expect<T> { /* private fields */ }
The main Expect wrapper for fluent assertions

Implementations

Source

impl<T> Expect<T>

pub fn new(value: T, location: &'static str) -> Self

Create a new Expect wrapper (use the expect! macro instead)

Source

impl<T: Debug + PartialEq> Expect<T>

pub fn to_equal(&self, expected: T)

Assert that the value equals the expected value

Example
expect!(actual).to_equal(expected);
pub fn to_not_equal(&self, unexpected: T)

Assert that the value does not equal the unexpected value

Example
expect!(actual).to_not_equal(unexpected);
Source

impl Expect<bool>

pub fn to_be_true(&self)

Assert that the value is true

Example
expect!(condition).to_be_true();
pub fn to_be_false(&self)

Assert that the value is false

Example
expect!(condition).to_be_false();
Source

impl<T: Debug> Expect<Option<T>>

pub fn to_be_some(&self)

Assert that the Option is Some

Example
expect!(option).to_be_some();
pub fn to_be_none(&self)

Assert that the Option is None

Example
expect!(option).to_be_none();
Source

impl<T: Debug + PartialEq> Expect<Option<T>>

pub fn to_contain_value(&self, expected: T)

Assert that the Option contains the expected value

Example
expect!(Some(5)).to_contain_value(5);
Source

impl<T: Debug, E: Debug> Expect<Result<T, E>>

pub fn to_be_ok(&self)

Assert that the Result is Ok

Example
expect!(result).to_be_ok();
pub fn to_be_err(&self)

Assert that the Result is Err

Example
expect!(result).to_be_err();
Source

impl Expect<String>

pub fn to_contain(&self, substring: &str)

Assert that the string contains the substring

Example
expect!(string).to_contain("hello");
pub fn to_start_with(&self, prefix: &str)

Assert that the string starts with the prefix

Example
expect!(string).to_start_with("hello");
pub fn to_end_with(&self, suffix: &str)

Assert that the string ends with the suffix

Example
expect!(string).to_end_with("world");
pub fn to_have_length(&self, expected: usize)

Assert that the string has the expected length

Example
expect!(string).to_have_length(5);
pub fn to_be_empty(&self)

Assert that the string is empty

Example
expect!(string).to_be_empty();
Source

impl Expect<&str>

pub fn to_contain(&self, substring: &str)

Assert that the string contains the substring

pub fn to_start_with(&self, prefix: &str)

Assert that the string starts with the prefix

pub fn to_end_with(&self, suffix: &str)

Assert that the string ends with the suffix

pub fn to_have_length(&self, expected: usize)

Assert that the string has the expected length

pub fn to_be_empty(&self)

Assert that the string is empty

Source

impl<T: Debug + PartialEq> Expect<Vec<T>>

pub fn to_have_length(&self, expected: usize)

Assert that the Vec has the expected length

Example
expect!(vec).to_have_length(3);
pub fn to_contain(&self, item: &T)

Assert that the Vec contains the item

Example
expect!(vec).to_contain(&item);
pub fn to_be_empty(&self)

Assert that the Vec is empty

Example
expect!(vec).to_be_empty();
Source

impl<T: Debug + PartialOrd> Expect<T>

pub fn to_be_greater_than(&self, expected: T)

Assert that the value is greater than the expected value

Example
expect!(10).to_be_greater_than(5);
pub fn to_be_less_than(&self, expected: T)

Assert that the value is less than the expected value

Example
expect!(5).to_be_less_than(10);
pub fn to_be_greater_than_or_equal(&self, expected: T)

Assert that the value is greater than or equal to the expected value

Example
expect!(10).to_be_greater_than_or_equal(10);
pub fn to_be_less_than_or_equal(&self, expected: T)

Assert that the value is less than or equal to the expected value

Example
expect!(5).to_be_less_than_or_equal(5);