Fake

Struct Fake 

pub struct Fake;
Helper for generating fake data

Provides convenient methods for generating common types of fake data.

Example

use ferro_rs::testing::Fake;

let name = Fake::name();
let email = Fake::email();
let sentence = Fake::sentence();

Implementations

Source

impl Fake

pub fn first_name() -> String

Generate a random first name

pub fn last_name() -> String

Generate a random last name

pub fn name() -> String

Generate a random full name

pub fn email() -> String

Generate a random email address

pub fn safe_email() -> String

Generate a safe email (always @example.com)

pub fn username() -> String

Generate a random username

pub fn password() -> String

Generate a random password (for testing only)

pub fn sentence() -> String

Generate a random sentence

pub fn paragraph() -> String

Generate a random paragraph

pub fn text(approx_length: usize) -> String

Generate random text of approximately the given length

pub fn number(min: i64, max: i64) -> i64

Generate a random integer in a range

pub fn float(min: f64, max: f64) -> f64

Generate a random float in a range

pub fn boolean() -> bool

Generate a random boolean

pub fn boolean_with_probability(probability: f64) -> bool

Generate a random boolean with given probability of true

pub fn uuid() -> String

Generate a random UUID v4

pub fn phone() -> String

Generate a random phone number

pub fn address() -> String

Generate a random street address

pub fn city() -> String

Generate a random city name

pub fn state() -> String

Generate a random US state

pub fn zip_code() -> String

Generate a random US zip code

pub fn country() -> String

Generate a random country

pub fn company() -> String

Generate a random company name

pub fn url() -> String

Generate a random URL

pub fn image_url(width: u32, height: u32) -> String

Generate a random image URL (placeholder)

pub fn hex_color() -> String

Generate a random hex color

pub fn ipv4() -> String

Generate a random IPv4 address

pub fn mac_address() -> String

Generate a random MAC address

pub fn date() -> String

Generate a random date in YYYY-MM-DD format

pub fn datetime() -> String

Generate a random datetime in ISO 8601 format

pub fn future_date() -> String

Generate a random future date

pub fn past_date() -> String

Generate a random past date

pub fn slug() -> String

Generate a random slug from words

pub fn one_of<T: Clone>(items: &[T]) -> T

Pick a random element from a slice

pub fn many_of<T: Clone>(items: &[T], count: usize) -> Vec<T>

Pick n random elements from a slice

pub fn credit_card() -> String

Generate a random credit card number (for testing only, not valid)

pub fn bytes(length: usize) -> Vec<u8>

Generate random bytes

pub fn hex(length: usize) -> String

Generate a random hex string