pub struct Sequence { /* private fields */ }Expand description
Convenience function to create a sequence of unique items
Implementations
Sourceimpl Sequence
impl Sequence
Sourcepub fn starting_at(value: usize) -> Self
pub fn starting_at(value: usize) -> Self
Create a sequence starting at a specific value
Sourcepub fn next_with_prefix(&mut self, prefix: &str) -> String
pub fn next_with_prefix(&mut self, prefix: &str) -> String
Get the next value as a string with prefix