Application

Struct Application 

pub struct Application<M = NoMigrator>
where M: MigratorTrait,
{ /* private fields */ }
Application builder for Ferro framework

Use this to configure and run your Ferro application with a fluent API.

Implementations

Source

impl Application<NoMigrator>

pub fn new() -> Self

Create a new application builder

Source

impl<M> Application<M>
where M: MigratorTrait,

pub fn config<F>(self, f: F) -> Self
where F: FnOnce() + 'static,

Register a configuration function

This function is called early during startup to register application configuration.

Example
App::new()
    .config(config::register_all)
pub fn bootstrap<F, Fut>(self, f: F) -> Self
where F: FnOnce() -> Fut + Send + 'static, Fut: Future<Output = ()> + Send + 'static,

Register a bootstrap function

This async function is called to register services, middleware, and other application components.

Example
App::new()
    .bootstrap(bootstrap::register)
pub fn routes<F>(self, f: F) -> Self
where F: FnOnce() -> Router + Send + 'static,

Register a routes function

This function returns the application’s router configuration.

Example
App::new()
    .routes(routes::register)
pub fn migrations<NewM>(self) -> Application<NewM>
where NewM: MigratorTrait,

Configure the migrator type for database migrations

Example
Application::new()
    .migrations::<migrations::Migrator>()
pub fn seeders<F>(self, f: F) -> Self
where F: FnOnce() -> SeederRegistry + Send + 'static,

Register a seeders function

This function returns the application’s seeder registry for database seeding.

Example
Application::new()
    .seeders(seeders::register)
pub async fn run(self)

Run the application

This parses CLI arguments and executes the appropriate command:

  • serve (default): Run the web server
  • db:migrate: Run pending migrations
  • db:status: Show migration status
  • db:rollback: Rollback migrations
  • db:fresh: Drop and re-run all migrations
  • schedule:*: Scheduler commands