pub struct AuthUser<T>(pub T);Expand description
Extracts the authenticated user, returning 401 if not authenticated.
Use this in handler signatures where authentication is required. The handler macro will automatically extract the user from the session.
Type Parameters
T- The concrete user type implementingAuthenticatable + Clone
Example
ⓘ
#[handler]
pub async fn profile(user: AuthUser<User>) -> Response {
json_response!({ "id": user.id, "email": user.email })
}Tuple Fields
0: TTrait Implementations
Sourceimpl<T> FromRequest for AuthUser<T>where
T: Authenticatable + Clone + 'static,
impl<T> FromRequest for AuthUser<T>where
T: Authenticatable + Clone + 'static,