pub struct RateLimiter;Expand description
Static registry for named rate limiters
Register named limiters with closures that receive the request and return dynamic rate limits. Closures are evaluated per-request, enabling limits based on authentication state, user tier, or request properties.
Example
use ferro::middleware::{RateLimiter, Limit};
// Register in bootstrap
RateLimiter::define("api", |req| {
Limit::per_minute(60)
});
// Dynamic limits based on auth
RateLimiter::define("api", |req| {
match req.header("X-API-Key") {
Some(_) => Limit::per_minute(120),
None => Limit::per_minute(30),
}
});
// Multiple limits
RateLimiter::define("login", |req| {
vec![
Limit::per_minute(500),
Limit::per_minute(5).by("per-ip".to_string()),
]
});Implementations
Sourceimpl RateLimiter
impl RateLimiter
Sourcepub fn define<F, T>(name: &str, f: F)
pub fn define<F, T>(name: &str, f: F)
Register a named rate limiter
The closure receives &Request and returns a Limit or Vec<Limit>.
Sourcepub fn resolve(name: &str, req: &Request) -> Option<Vec<Limit>>
pub fn resolve(name: &str, req: &Request) -> Option<Vec<Limit>>
Resolve a named limiter for a given request
Returns None if the named limiter is not registered.
Sourcepub fn per_second(max: u32) -> Limit
pub fn per_second(max: u32) -> Limit
Create an inline limit of N requests per second
Sourcepub fn per_minute(max: u32) -> Limit
pub fn per_minute(max: u32) -> Limit
Create an inline limit of N requests per minute