pub type Next = Arc<dyn Fn(Request) -> MiddlewareFuture + Send + Sync>;Expand description
Type alias for the next handler in the middleware chain
Call next(request).await to pass control to the next middleware or the route handler.
Aliased Type
pub struct Next { /* private fields */ }