pub struct RouteDefBuilder<H> { /* private fields */ }Expand description
Builder for route definitions that supports .name() and .middleware() chaining
Implementations
Sourceimpl<H, Fut> RouteDefBuilder<H>
impl<H, Fut> RouteDefBuilder<H>
Sourcepub fn new(method: HttpMethod, path: &'static str, handler: H) -> Self
pub fn new(method: HttpMethod, path: &'static str, handler: H) -> Self
Create a new route definition builder
Sourcepub fn middleware<M: Middleware + 'static>(self, middleware: M) -> Self
pub fn middleware<M: Middleware + 'static>(self, middleware: M) -> Self
Add middleware to this route
Sourcepub fn mcp_tool_name(self, name: &str) -> Self
pub fn mcp_tool_name(self, name: &str) -> Self
Override the auto-generated MCP tool name for this route
Sourcepub fn mcp_description(self, desc: &str) -> Self
pub fn mcp_description(self, desc: &str) -> Self
Override the auto-generated MCP description for this route
Sourcepub fn mcp_hint(self, hint: &str) -> Self
pub fn mcp_hint(self, hint: &str) -> Self
Add a hint that is appended to the MCP description for AI guidance
Hide this route from MCP tool discovery
Sourceimpl<H, Fut> RouteDefBuilder<H>
impl<H, Fut> RouteDefBuilder<H>
Sourcepub fn into_group_route(self) -> GroupRoute
pub fn into_group_route(self) -> GroupRoute
Convert this route definition to a type-erased GroupRoute
This is used internally when adding routes to a group.