pub struct PendingDispatch<J> { /* private fields */ }Expand description
A pending job dispatch.
This builder allows configuring how a job is dispatched before actually sending it to the queue.
Implementations
Sourceimpl<J> PendingDispatch<J>
impl<J> PendingDispatch<J>
Sourcepub fn new(job: J) -> PendingDispatch<J>
pub fn new(job: J) -> PendingDispatch<J>
Create a new pending dispatch.
Sourcepub fn on_queue(self, queue: &'static str) -> PendingDispatch<J>
pub fn on_queue(self, queue: &'static str) -> PendingDispatch<J>
Set the queue to dispatch to.
Sourcepub fn delay(self, duration: Duration) -> PendingDispatch<J>
pub fn delay(self, duration: Duration) -> PendingDispatch<J>
Set a delay before the job is available for processing.
Sourcepub async fn dispatch(self) -> Result<(), Error>
pub async fn dispatch(self) -> Result<(), Error>
Dispatch the job to the queue.
In sync mode (QUEUE_CONNECTION=sync), the job is executed immediately
in the current task. This is useful for development and testing.
In redis mode (QUEUE_CONNECTION=redis), the job is pushed to the
Redis queue for background processing by a worker.
Sourcepub fn dispatch_now(self)where
J: Send + 'static,
pub fn dispatch_now(self)where
J: Send + 'static,
Dispatch the job in a background task (fire and forget).
This spawns the dispatch as a background task, useful when you don’t need to wait for the dispatch to complete.
Sourcepub fn dispatch_sync(self)where
J: Send + 'static,
👎Deprecated since 0.2.0: Use dispatch_now() instead
pub fn dispatch_sync(self)where
J: Send + 'static,
Dispatch the job synchronously (fire and forget).
This spawns the dispatch as a background task.