pub struct FactoryBuilder<T: Factory> { /* private fields */ }Expand description
Builder for creating model instances with customizations
Implementations
Sourceimpl<T: Factory> FactoryBuilder<T>
impl<T: Factory> FactoryBuilder<T>
Sourcepub fn set<V, F>(self, value: V, setter: F) -> Self
pub fn set<V, F>(self, value: V, setter: F) -> Self
Set a field value using a setter function
This is useful for setting foreign keys when creating associated models. The value is cloned for each model when creating multiple instances.
Example
ⓘ
// Create a user first, then create posts belonging to that user
let user = User::factory().create().await?;
let post = Post::factory()
.set(user.id, |p, user_id| p.user_id = user_id)
.create()
.await?;
// Create multiple posts for the same user
let posts = Post::factory()
.count(5)
.set(user.id, |p, user_id| p.user_id = user_id)
.create_many()
.await?;Sourcepub fn after_make<F>(self, f: F) -> Self
pub fn after_make<F>(self, f: F) -> Self
Sourcepub fn after_create<F, Fut>(self, f: F) -> Self
pub fn after_create<F, Fut>(self, f: F) -> Self
Sourceimpl<T: DatabaseFactory> FactoryBuilder<T>
impl<T: DatabaseFactory> FactoryBuilder<T>
Sourcepub async fn create(self) -> Result<T, FrameworkError>
pub async fn create(self) -> Result<T, FrameworkError>
Sourcepub async fn create_many(self) -> Result<Vec<T>, FrameworkError>
pub async fn create_many(self) -> Result<Vec<T>, FrameworkError>