pub struct TestClient { /* private fields */ }Expand description
HTTP test client for making requests to the application
Implementations
Sourceimpl TestClient
impl TestClient
Sourcepub fn with_router(router: Router) -> Self
pub fn with_router(router: Router) -> Self
Create a test client with a router for integration tests
Sourcepub fn with_header(self, name: &str, value: &str) -> Self
pub fn with_header(self, name: &str, value: &str) -> Self
Add a default header to all requests
Sourcepub fn get(&self, path: &str) -> TestRequestBuilder<'_>
pub fn get(&self, path: &str) -> TestRequestBuilder<'_>
Start building a GET request
Sourcepub fn post(&self, path: &str) -> TestRequestBuilder<'_>
pub fn post(&self, path: &str) -> TestRequestBuilder<'_>
Start building a POST request
Sourcepub fn put(&self, path: &str) -> TestRequestBuilder<'_>
pub fn put(&self, path: &str) -> TestRequestBuilder<'_>
Start building a PUT request
Sourcepub fn patch(&self, path: &str) -> TestRequestBuilder<'_>
pub fn patch(&self, path: &str) -> TestRequestBuilder<'_>
Start building a PATCH request
Sourcepub fn delete(&self, path: &str) -> TestRequestBuilder<'_>
pub fn delete(&self, path: &str) -> TestRequestBuilder<'_>
Start building a DELETE request